@@ -1,13 +1,14 @@
 img_detrend_smoothed <- function(arr3d, arr3d_smoothed, purpose, parallel) {
   checkmate::assert_string(purpose)
-  stopifnot(purpose %in% c("fcs", "ffs"))
+  purpose %<>% filesstrings::match_arg(c("fcs", "ffs"), ignore_case = TRUE)
   arr3d_smoothed[arr3d_smoothed < 0] <- 0
   deviations_from_smoothed <- arr3d - arr3d_smoothed
   pillar_means <- as.vector(mean_pillars(arr3d, parallel = parallel))
   if (purpose == "ffs") {
     variance_correction_factors <- square_root(pillar_means /
-                                                 arr3d_smoothed,
-                                               parallel = parallel) %T>% {
+      arr3d_smoothed,
+    parallel = parallel
+    ) %T>% {
       .[!is.finite(.)] <- 1
     }
     deviations_from_smoothed <- deviations_from_smoothed *
@@ -16,41 +17,79 @@ img_detrend_smoothed <- function(arr3d, arr3d_smoothed, purpose, parallel) {
   }
   out_real <- pillar_means + deviations_from_smoothed
   rm(deviations_from_smoothed)
-  out_int <- floor(out_real) %>%
-    {. + myrbern(out_real - ., parallel = parallel)}
+  out_int <- floor(out_real) %>% {
+    . + myrbern(out_real - ., parallel = parallel)
+  }
   dim(out_int) <- dim(arr3d)
   out_int
 }
 
 img_detrend_tau_specified <- function(arr3d, tau, cutoff, purpose,
                                       parallel) {
+  checkmate::assert_array(arr3d)
+  if (length(dim(arr3d)) == 4 && dim(arr3d)[3] == 1) {
+    dim(arr3d) %<>% {
+      .[-3]
+    }
+  }
+  checkmate::assert_array(arr3d, d = 3)
   if (is.na(tau)) return(arr3d)
   d <- dim(arr3d)
-  l <- min(floor(- tau * log(cutoff)), d[3] %>% {(. - 1) + (. - 2)})
+  l <- min(floor(-tau * log(cutoff)), d[3] %>% {
+    (. - 1) + (. - 2)
+  })
   smoothed <- exp_smooth_pillars(arr3d, tau, l, parallel = parallel)
-  img_detrend_smoothed(arr3d, smoothed, purpose = purpose,
-                       parallel = parallel)
+  img_detrend_smoothed(arr3d, smoothed,
+    purpose = purpose,
+    parallel = parallel
+  )
 }
 
 img_detrend_l_specified <- function(arr3d, l, purpose, parallel) {
+  checkmate::assert_array(arr3d)
+  if (length(dim(arr3d)) == 4 && dim(arr3d)[3] == 1) {
+    dim(arr3d) %<>% {
+      .[-3]
+    }
+  }
+  checkmate::assert_array(arr3d, d = 3)
   if (is.na(l)) return(arr3d)
   d <- dim(arr3d)
-  l <- min(l, d[3] %>% {(. - 1) + (. - 2)})
+  l <- min(l, d[3] %>% {
+    (. - 1) + (. - 2)
+  })
   smoothed <- boxcar_smooth_pillars(arr3d, l, parallel = parallel)
-  img_detrend_smoothed(arr3d, smoothed, purpose = purpose,
-                       parallel = parallel)
+  img_detrend_smoothed(arr3d, smoothed,
+    purpose = purpose,
+    parallel = parallel
+  )
 }
 
 img_detrend_degree_specified <- function(arr3d, degree, purpose,
                                          parallel) {
+  checkmate::assert_array(arr3d)
+  if (length(dim(arr3d)) == 4 && dim(arr3d)[3] == 1) {
+    dim(arr3d) %<>% {
+      .[-3]
+    }
+  }
+  checkmate::assert_array(arr3d, d = 3)
   if (is.na(degree)) return(arr3d)
   d <- dim(arr3d)
   smoothed <- poly_fit_pillars(arr3d, degree, parallel = parallel)
-  img_detrend_smoothed(arr3d, smoothed, purpose = purpose,
-                       parallel = parallel)
+  img_detrend_smoothed(arr3d, smoothed,
+    purpose = purpose,
+    parallel = parallel
+  )
 }
 
 img_detrend_swaps_specified <- function(arr3d, swaps) {
+  checkmate::assert_array(arr3d)
+  if (length(dim(arr3d)) == 4 && dim(arr3d)[3] == 1) {
+    dim(arr3d) %<>% {
+      .[-3]
+    }
+  }
   checkmate::assert_array(arr3d, d = 3)
   checkmate::assert_numeric(arr3d, lower = 0, upper = .Machine$integer.max)
   checkmate::assert_integerish(arr3d)
@@ -58,42 +97,62 @@ img_detrend_swaps_specified <- function(arr3d, swaps) {
   frame_sums <- sum_frames(arr3d, na_rm = TRUE)
   frame_sum_mean <- mean(frame_sums)
   frame_weights <- frame_sums - frame_sum_mean
-  frame_balls <- frame_weights %T>%
-    {.[. < 0] <- 0}
+  frame_balls <- frame_weights %T>% {
+    .[. < 0] <- 0
+  }
   frame_ball_leftovers <- frame_balls %% 1
   frame_balls %<>% {
     floor(.) + rtoboxes(floor(sum(frame_ball_leftovers)), d[3],
-                        weights = frame_ball_leftovers,
-                        capacities = rep(1, d[3]))
+      weights = frame_ball_leftovers,
+      capacities = rep(1, d[3])
+    )
+  }
+  frame_capacities <- -frame_weights %T>% {
+    .[. < 0] <- 0
   }
-  frame_capacities <- -frame_weights %T>%
-    {.[. < 0] <- 0}
   frame_capacity_leftovers <- frame_capacities %% 1
   frame_capacities %<>% {
     floor(.) + rtoboxes(floor(sum(frame_capacity_leftovers)), d[3],
-                        weights = frame_capacity_leftovers,
-                        capacities = rep(1, d[3]))
+      weights = frame_capacity_leftovers,
+      capacities = rep(1, d[3])
+    )
   }
   max_swaps <- min(sum(frame_balls), sum(frame_capacities))
-  msg <- paste("Your image is too close to zero. Can't detrend an image with",
-               "so few nonzero values. \n* `img` has",
-               length(arr3d), "elements",
-               "and just", sum(arr3d > 0), "of them are greater than zero.")
-  if (max_swaps == 0) stop(msg)
+  if (max_swaps == 0) {
+    custom_stop(
+      "Your image is too close to zero.",
+      "Can't detrend an image with so few nonzero values.",
+      "
+      `img` has {length(arr3d)} elements and just {sum(arr3d > 0)}
+      of them are greater than zero.
+      "
+    )
+  }
   swaps %<>% min(max_swaps)
-  weights <- frame_weights %T>% {.[. < 0] <- 0}
-  frames_losing <- rfromboxes(n = swaps, balls = frame_balls,
-                              weights = weights)
+  weights <- frame_weights %T>% {
+    .[. < 0] <- 0
+  }
+  frames_losing <- rfromboxes(
+    n = swaps, balls = frame_balls,
+    weights = weights
+  )
   px_losing <- px_take_arr3d(arr3d, frames_losing, get_seed())
-  arr3d %<>% {. - px_losing}
+  arr3d %<>% {
+    . - px_losing
+  }
   px_getting <- sum_pillars(px_losing) %>%
     as.vector() %>%
     rep(seq_along(.), times = .) %>%
     arrayInd(.dim = d[1:2])
-  weights <- (-frame_weights) %T>% {.[. < 0] <- 0}
-  frames_getting <- rtoboxes(swaps, d[3], weights = weights,
-                             capacities = frame_capacities) %>%
-    rep(seq_along(.), times = .) %>% {
+  weights <- (-frame_weights) %T>% {
+    .[. < 0] <- 0
+  }
+  frames_getting <- rtoboxes(swaps, d[3],
+    weights = weights,
+    capacities = frame_capacities
+  ) %>%
+    rep(seq_along(.), times = .) %>%
+    {
       if (length(.) <= 1) return(.)
       sample(.)
     }
@@ -178,6 +237,8 @@ NULL
 
 #' @rdname detrending
 #'
+#' @inheritParams best_swaps
+#'
 #' @references Rory Nolan, Luis A. J. Alvarez, Jonathan Elegheert, Maro
 #'   Iliopoulou, G. Maria Jakobsdottir, Marina Rodriguez-Muñoz, A. Radu
 #'   Aricescu, Sergi Padilla-Parra; nandb—number and brightness in R with a
@@ -185,13 +246,13 @@ NULL
 #'   https://doi.org/10.1093/bioinformatics/btx434.
 #'
 #' @examples
-#' img <- ijtiff::read_tif(system.file('extdata', 'bleached.tif',
-#'                                     package = 'detrendr'))
-#' corrected <- img_detrend_rh(img)
 #' \dontrun{
 #' ## These examples are not run on CRAN because they take too long.
 #' ## You can still try them for yourself.
 #'
+#' img <- ijtiff::read_tif(system.file('extdata', 'bleached.tif',
+#'                                     package = 'detrendr'))
+#' corrected <- img_detrend_rh(img)
 #' corrected <- img_detrend_boxcar(img, "auto", purpose = "fcs", parallel = 2)
 #' corrected10 <- img_detrend_boxcar(img, 10, purpose = "fcs", parallel = 2)
 #' corrected50 <- img_detrend_boxcar(img, 50, purpose = "fcs", parallel = 2)
@@ -202,50 +263,67 @@ NULL
 #' corrected2 <- img_detrend_polynom(img, 2, purpose = "ffs", parallel = 2)
 #' }
 #' @export
-img_detrend_robinhood <- function(img, swaps = "auto") {
+img_detrend_robinhood <- function(img, swaps = "auto", quick = FALSE) {
   checkmate::assert_array(img, min.d = 3, max.d = 4)
   checkmate::assert_integerish(img, lower = 0)
-  if (length(dim(img)) == 3) dim(img) %<>% {c(.[1:2], 1, .[3])}
+  img %<>% ijtiff::as_ijtiff_img()
   n_ch <- dim(img)[3]
   out <- array(0, dim = dim(img))
   if (length(swaps) == 1) swaps %<>% rep(n_ch)
   swaps %<>% as.list()
   if (length(swaps) != n_ch) {
-    stop("Argument `swaps` must have length 1 or length equal to ",
-         "the number of channels. \n",
-         "    * Your `swaps` argument has length ", length(swaps), " and your ",
-         "image has ", n_ch, " channels.")
+    custom_stop("
+      Argument `swaps` must have length 1 or length equal to
+      the number of channels.
+      ", "
+      Your `swaps` argument has length {length(swaps)} and your
+      image has {n_ch} channels.
+      ")
   }
   auto <- rep(FALSE, n_ch)
   for (i in seq_len(n_ch)) {
     if (is.na(swaps[[i]])) {
       out[, , i, ] <- img[, , i, ]
     } else if (is.numeric(swaps[[i]]) |
-               (is.character(swaps[[i]]) &&
-                filesstrings::can_be_numeric(swaps[[i]]))) {
-      swaps[[i]] %<>% as.numeric() %>% floor()
+      (is.character(swaps[[i]]) &&
+        filesstrings::can_be_numeric(swaps[[i]]))) {
+      swaps[[i]] %<>% as.numeric() %>% floor(.)
       if (swaps[[i]] == 0) {
         out[, , i, ] <- img[, , i, ]
       } else {
         if (swaps[[i]] < 0) {
-          stop("`swaps` must be greater than or equal to zero.", "\n",
-               "    * You have `swaps` equal to ", swaps[[i]], ".")
+          custom_stop(
+            "`swaps` must be greater than or equal to zero.",
+            "You have `swaps` equal to {swaps[[i]]}."
+          )
         }
-        out[, , i, ] <- img_detrend_swaps_specified(img[, , i, ], swaps[[i]])
+        out[, , i, ] <- img_detrend_swaps_specified(
+          img[, , i, , drop = FALSE],
+          swaps[[i]]
+        ) %>%
+          as.vector()
       }
     } else if (is.character(swaps[[i]])) {
       swaps[[i]] %<>% tolower()
-      if (startsWith("auto", swaps[[i]])) {
+      if (stringi::stri_startswith_coll("auto", swaps[[i]])) {
         auto[[i]] <- TRUE
-        swaps[[i]] <- best_swaps(img[, , i, ])
-        out[, , i, ] <- img_detrend_swaps_specified(img[, , i, ], swaps[[i]])
+        swaps[[i]] <- best_swaps(img[, , i, , drop = FALSE], quick = quick)
+        out[, , i, ] <- img_detrend_swaps_specified(
+          img[, , i, , drop = FALSE],
+          swaps[[i]]
+        ) %>%
+          as.vector()
       } else {
-        stop("If `swaps` is a string, the only permissible value is 'auto'.",
-             "\n", "    * You have used '", swaps[[i]], "'.")
+        custom_stop(
+          "If `swaps` is a string, the only permissible value is 'auto'.",
+          "You have used '{swaps[[i]]}'."
+        )
       }
     } else {
-      stop("`swaps` must be specified as a positive number or as 'auto'.", "\n",
-           "    * You have used '", swaps[[i]], "'.")
+      custom_stop(
+        "`swaps` must be specified as a positive number or as 'auto'.",
+        "You have used '{swaps[[i]]}'."
+      )
     }
   }
   detrended_img(out, "rh", as.integer(unlist(swaps)), auto)
@@ -261,55 +339,72 @@ img_detrend_boxcar <- function(img, l, purpose = c("FCS", "FFS"),
                                parallel = FALSE) {
   checkmate::assert_array(img, min.d = 3, max.d = 4)
   checkmate::assert_numeric(img, lower = 0)
-  if (filesstrings::all_equal(purpose, c("FCS", "FFS")))
-    stop("You must choose *either* 'FCS' *or* 'FFS' for `purpose`.")
+  if (filesstrings::all_equal(purpose, c("FCS", "FFS"))) {
+    custom_stop("You must choose *either* 'FCS' *or* 'FFS' for `purpose`.")
+  }
   checkmate::assert_string(purpose)
   purpose %<>% filesstrings::match_arg(c("fcs", "ffs"), ignore_case = TRUE)
-  if (length(dim(img)) == 3) dim(img) %<>% {c(.[1:2], 1, .[3])}
+  img %<>% ijtiff::as_ijtiff_img()
   n_ch <- dim(img)[3]
   out <- array(0, dim = dim(img))
   if (length(l) == 1) l %<>% rep(n_ch)
   l %<>% as.list()
   if (length(l) != n_ch) {
-    stop("Argument l must have length 1 or length equal to ",
-         "the number of channels. \n",
-         "    * Your l argument has length ", length(l), " and your ",
-         "image has ", n_ch, " channels.")
+    custom_stop("
+      Argument `l` must have length 1 or length equal to the number of channels.
+      ", "
+      Your l argument has length {length(l)} and your image has
+      {n_ch} channels.")
   }
   auto <- rep(FALSE, n_ch)
   for (i in seq_len(n_ch)) {
     if (is.na(l[[i]])) {
       out[, , i, ] <- img[, , i, ]
     } else if (is.numeric(l[[i]]) |
-               (is.character(l[[i]]) &&
-                filesstrings::can_be_numeric(l[[i]]))) {
+      (is.character(l[[i]]) &&
+        filesstrings::can_be_numeric(l[[i]]))) {
       l[[i]] %<>% as.numeric()
       if (!isTRUE(checkmate::check_int(l[[i]]))) {
-        stop("`l` must be an integer.", "\n",
-             "    * You have `l` equal to ", l[[i]], ".")
+        custom_stop(
+          "`l` must be an integer.",
+          "You have `l` equal to {l[[i]]}."
+        )
       }
       if (l[[i]] <= 0) {
-        stop("`l` must be greater than zero.", "\n",
-             "    * You have `l` equal to ", l[[i]], ".")
+        custom_stop(
+          "`l` must be greater than zero.",
+          "You have `l` equal to {l[[i]]}."
+        )
       }
-      out[, , i, ] <- img_detrend_l_specified(img[, , i, ], l[[i]],
-                                              purpose = purpose,
-                                              parallel = parallel)
+      out[, , i, ] <- img_detrend_l_specified(img[, , i, , drop = FALSE],
+        l[[i]],
+        purpose = purpose,
+        parallel = parallel
+      ) %>%
+        as.vector()
     } else if (is.character(l[[i]])) {
       l[[i]] %<>% tolower()
-      if (startsWith("auto", l[[i]])) {
+      if (stringi::stri_startswith_coll("auto", l[[i]])) {
         auto[[i]] <- TRUE
-        l[[i]] <- best_l(img[, , i, ], parallel = parallel, purpose = purpose)
+        l[[i]] <- best_l(img[, , i, , drop = FALSE],
+          parallel = parallel, purpose = purpose
+        )
         out[, , i, ] <- img_detrend_l_specified(img[, , i, ], l[[i]],
-                                                purpose = purpose,
-                                                parallel = parallel)
+          purpose = purpose,
+          parallel = parallel
+        ) %>%
+          as.vector()
       } else {
-        stop("If `l` is a string, the only permissible value is 'auto'.", "\n",
-             "    * You have used '", l[[i]], "'.")
+        custom_stop(
+          "If `l` is a string, the only permissible value is 'auto'.",
+          "You have used '{l[[i]]}."
+        )
       }
     } else {
-      stop("`l` must be specified as a positive number or as 'auto'.", "\n",
-           "    * You have used '", l[[i]], "'.")
+      custom_stop(
+        "`l` must be specified as a positive number or as 'auto'.",
+        "You have used '{l[[i]]}'."
+      )
     }
   }
   detrended_img(out, "boxcar", as.integer(unlist(l)), auto, purpose = purpose)
@@ -320,58 +415,75 @@ img_detrend_boxcar <- function(img, l, purpose = c("FCS", "FFS"),
 img_detrend_exp <- function(img, tau, cutoff = 0.05, purpose = c("FCS", "FFS"),
                             parallel = FALSE) {
   checkmate::assert_array(img, min.d = 3, max.d = 4)
-  if (filesstrings::all_equal(purpose, c("FCS", "FFS")))
-    stop("You must choose *either* 'FCS' *or* 'FFS' for `purpose`.")
+  if (filesstrings::all_equal(purpose, c("FCS", "FFS"))) {
+    custom_stop("You must choose *either* 'FCS' *or* 'FFS' for `purpose`.")
+  }
   checkmate::assert_string(purpose)
   purpose %<>% filesstrings::match_arg(c("fcs", "ffs"), ignore_case = TRUE)
-  if (length(dim(img)) == 3) dim(img) %<>% {c(.[1:2], 1, .[3])}
+  img %<>% ijtiff::as_ijtiff_img()
   n_ch <- dim(img)[3]
   out <- array(0, dim = dim(img))
   if (length(tau) == 1) tau %<>% rep(n_ch)
   tau %<>% as.list()
   if (length(tau) != n_ch) {
-    stop("Argument `tau` must have length 1 or length equal to ",
-         "the number of channels. \n",
-         "    * Your tau argument has length ", length(tau), " and your ",
-         "image has ", n_ch, " channels.")
+    custom_stop("
+      Argument `tau` must have length 1 or length equal to
+      the number of channels.
+      ", "
+      Your `tau` argument has length {length(tau)} and your
+      image has {n_ch} channels.
+      ")
   }
   auto <- rep(FALSE, n_ch)
   for (i in seq_len(n_ch)) {
     if (is.na(tau[[i]])) {
       out[, , i, ] <- img[, , i, ]
     } else if (is.numeric(tau[[i]]) |
-               (is.character(tau[[i]]) &&
-                filesstrings::can_be_numeric(tau[[i]]))) {
-      tau[[i]] %<>% as.numeric() %>% floor()
+      (is.character(tau[[i]]) &&
+        filesstrings::can_be_numeric(tau[[i]]))) {
+      tau[[i]] %<>% as.numeric() %>% floor(.)
       if (tau[[i]] <= 0) {
-        stop("`tau` must be greater than zero.", "\n",
-             "    * You have `tau` equal to ", tau[[i]], ".")
+        custom_stop(
+          "`tau` must be greater than zero.",
+          "You have `tau` equal to {tau[[i]]}."
+        )
       }
-      out[, , i, ] <- img_detrend_tau_specified(img[, , i, ],
-                                                tau[[i]], cutoff,
-                                                purpose = purpose,
-                                                parallel = parallel)
+      out[, , i, ] <- img_detrend_tau_specified(img[, , i, , drop = FALSE],
+        tau[[i]], cutoff,
+        purpose = purpose,
+        parallel = parallel
+      ) %>%
+        as.vector()
     } else if (is.character(tau[[i]])) {
       tau[[i]] %<>% tolower()
-      if (startsWith("auto", tau[[i]])) {
+      if (stringi::stri_startswith_coll("auto", tau[[i]])) {
         auto[[i]] <- TRUE
-        tau[[i]] <- best_tau(img[, , i, ], cutoff = cutoff, purpose = purpose,
-                             parallel = parallel)
-        out[, , i, ] <- img_detrend_tau_specified(img[, , i, ],
-                                                  tau[[i]], cutoff,
-                                                  purpose = purpose,
-                                                  parallel = parallel)
+        tau[[i]] <- best_tau(img[, , i, , drop = FALSE],
+          cutoff = cutoff, purpose = purpose,
+          parallel = parallel
+        )
+        out[, , i, ] <- img_detrend_tau_specified(img[, , i, , drop = FALSE],
+          tau[[i]], cutoff,
+          purpose = purpose,
+          parallel = parallel
+        ) %>%
+          as.vector()
       } else {
-        stop("If `tau` is a string, the only permissible value is 'auto'.",
-             "\n", "    * You have used '", tau[[i]], "'.")
+        custom_stop(
+          "If `tau` is a string, the only permissible value is 'auto'.",
+          "You have used '{tau[[i]]}'."
+        )
       }
     } else {
-      stop("`tau` must be specified as a positive number or as 'auto'.",
-           "\n", "    * You have used '", tau[[i]], "'.")
+      custom_stop(
+        "`tau` must be specified as a positive number or as 'auto'.",
+        "You have used {tau[[i]]}'."
+      )
     }
   }
   detrended_img(out, "exponential", as.numeric(unlist(tau)), auto,
-                purpose = purpose)
+    purpose = purpose
+  )
 }
 
 #' @rdname detrending
@@ -379,60 +491,77 @@ img_detrend_exp <- function(img, tau, cutoff = 0.05, purpose = c("FCS", "FFS"),
 img_detrend_polynom <- function(img, degree, purpose = c("FCS", "FFS"),
                                 parallel = FALSE) {
   checkmate::assert_array(img, min.d = 3, max.d = 4)
-  if (filesstrings::all_equal(purpose, c("FCS", "FFS")))
-    stop("You must choose *either* 'FCS' *or* 'FFS' for `purpose`.")
+  if (filesstrings::all_equal(purpose, c("FCS", "FFS"))) {
+    custom_stop("You must choose *either* 'FCS' *or* 'FFS' for `purpose`.")
+  }
   checkmate::assert_string(purpose)
   purpose %<>% filesstrings::match_arg(c("fcs", "ffs"), ignore_case = TRUE)
-  if (length(dim(img)) == 3) dim(img) %<>% {c(.[1:2], 1, .[3])}
+  img %<>% ijtiff::as_ijtiff_img()
   n_ch <- dim(img)[3]
   out <- array(0, dim = dim(img))
   if (length(degree) == 1) degree %<>% rep(n_ch)
   degree %<>% as.list()
   if (length(degree) != n_ch) {
-    stop("Argument degree must have length 1 or length equal to ",
-         "the number of channels. \n",
-         "    * Your degree argument has length ", length(degree), " and your ",
-         "image has ", n_ch, " channels.")
+    custom_stop("
+      Argument degree must have length 1 or length equal to
+      the number of channels
+      ", "
+      Your degree argument has length {length(degree)} and your
+      image has {n_ch} channels.
+      ")
   }
   auto <- rep(FALSE, n_ch)
   for (i in seq_len(n_ch)) {
     if (is.na(degree[[i]])) {
       out[, , i, ] <- img[, , i, ]
     } else if (is.numeric(degree[[i]]) |
-               (is.character(degree[[i]]) &&
-                filesstrings::can_be_numeric(degree[[i]]))) {
+      (is.character(degree[[i]]) &&
+        filesstrings::can_be_numeric(degree[[i]]))) {
       degree[[i]] %<>% as.numeric()
       if (!isTRUE(checkmate::check_int(degree[[i]]))) {
-        stop("`degree` must be an integer.", "\n",
-             "    * You have `degree` equal to ", degree[[i]], ".")
+        custom_stop(
+          "`degree` must be an integer.",
+          "You have `degree` equal to {degree[[i]]}."
+        )
       }
       if (degree[[i]] <= 0) {
-        stop("`degree` must be greater than zero.", "\n",
-             "    * You have `degree` equal to ", degree[[i]], ".")
+        custom_stop(
+          "`degree` must be greater than zero.",
+          "You have `degree` equal to {degree[[i]]}."
+        )
       }
-      out[, , i, ] <- img_detrend_degree_specified(img[, , i, ],
-                                                   degree[[i]],
-                                                   purpose = purpose,
-                                                   parallel = parallel)
+      out[, , i, ] <- img_detrend_degree_specified(img[, , i, , drop = FALSE],
+        degree[[i]],
+        purpose = purpose,
+        parallel = parallel
+      ) %>%
+        as.vector()
     } else if (is.character(degree[[i]])) {
       degree[[i]] %<>% tolower()
-      if (startsWith("auto", degree[[i]])) {
-        degree[[i]] <- best_degree(img[, , i, ], purpose = purpose,
-                                   parallel = parallel)
-        out[, , i, ] <- img_detrend_degree_specified(img[, , i, ],
-                                                     degree[[i]],
-                                                     purpose = purpose,
-                                                     parallel = parallel)
+      if (stringi::stri_startswith_coll("auto", degree[[i]])) {
+        degree[[i]] <- best_degree(img[, , i, , drop = FALSE],
+          purpose = purpose, parallel = parallel
+        )
+        out[, , i, ] <- img_detrend_degree_specified(img[, , i, , drop = FALSE],
+          degree[[i]],
+          purpose = purpose,
+          parallel = parallel
+        ) %>%
+          as.vector()
       } else {
-        stop("If `degree` is a string, the only permissible value is 'auto'.",
-             "\n", "    * You have used '", degree[[i]], "'.")
+        custom_stop(
+          "If `degree` is a string, the only permissible value is 'auto'.",
+          "You have used '{degree[[i]]}'."
+        )
       }
     } else {
-      stop("`degree` must be specified as a positive number or as 'auto'.",
-           "\n", "    * You have used '", degree[[i]], "'.")
+      custom_stop(
+        "`degree` must be specified as a positive number or as 'auto'.",
+        "You have used '{degree[[i]]}'."
+      )
     }
   }
   detrended_img(out, "polynomial", as.numeric(unlist(degree)), auto,
-                purpose = purpose)
+    purpose = purpose
+  )
 }
-
