@@ -29,21 +29,21 @@ test_that("pillar-stats works", {
   skip_if_not_installed("abind")
   ans <- purrr::map(seq_len(dim(aaaa)[3]), ~mean_pillars(aaaa[, , ., ])) %>%
     purrr::reduce(~abind::abind(.x, .y, along = 3)) %>%
-    rlang::set_attrs(dimnames = NULL)
+    structure(dimnames = NULL)
   expect_equal(
     ijtiff::ijtiff_img(mean_pillars(aaaa)),
     ijtiff::ijtiff_img(ans)
   )
   ans <- purrr::map(seq_len(dim(aaaa)[3]), ~median_pillars(aaaa[, , ., ])) %>%
     purrr::reduce(~abind::abind(.x, .y, along = 3)) %>%
-    rlang::set_attrs(dimnames = NULL)
+    structure(dimnames = NULL)
   expect_equal(
     ijtiff::ijtiff_img(median_pillars(aaaa)),
     ijtiff::ijtiff_img(ans)
   )
   ans <- purrr::map(seq_len(dim(aaaa)[3]), ~var_pillars(aaaa[, , ., ])) %>%
     purrr::reduce(~abind::abind(.x, .y, along = 3)) %>%
-    rlang::set_attrs(dimnames = NULL)
+    structure(dimnames = NULL)
   expect_equal(
     ijtiff::ijtiff_img(var_pillars(aaaa)),
     ijtiff::ijtiff_img(ans)
@@ -53,7 +53,7 @@ test_that("pillar-stats works", {
     ~brightness_pillars(aaaa[, , ., ])
   ) %>%
     purrr::reduce(~abind::abind(.x, .y, along = 3)) %>%
-    rlang::set_attrs(dimnames = NULL)
+    structure(dimnames = NULL)
   expect_equal(
     ijtiff::ijtiff_img(brightness_pillars(aaaa)),
     ijtiff::ijtiff_img(ans)
