@@ -116,7 +116,11 @@ test_that("rboxes derivatives error correctly", {
 
 test_that("`myarray2vec()` works", {
   skip_if_not_installed("arrayhelpers")
-  mat <- matrix(sample.int(4 * 4), nrow = 4)
+  mat <- matrix(c(9, 13, 2, 6,
+                  7, 5, 15, 12,
+                  1, 10, 3, 8,
+                  4, 11, 16, 14),
+                nrow = 4, byrow = TRUE)
   d <- rep(99, 4)
   expect_equal(myarray2vec(mat, d), arrayhelpers::array2vec(mat, d))
   expect_error(
@@ -129,7 +133,11 @@ test_that("`myarray2vec()` works", {
   )
   set.seed(2)
   expect_error(
-    myarray2vec(matrix(sample.int(5, 100, replace = TRUE), ncol = 4),
+    myarray2vec(matrix(c(1, 3, 1, 4,
+                         4, 1, 1, 2,
+                         3, 2, 4, 5,
+                         1, 5, 5, 3),
+                       nrow = 4, byrow = TRUE),
       dim = rep(4, 4)
     ),
     paste0(
@@ -143,16 +151,3 @@ test_that("`myarray2vec()` works", {
   vec <- sample.int(max(d), length(d))
   expect_equal(myarray2vec(vec, d), myarray2vec(matrix(vec, nrow = 1), d))
 })
-
-test_that("`ptem()` works", {
-  skip_if_not(identical(Sys.getenv("TRAVIS"), "true"))
-  ptem_pkgs <- c("clipr", "styler", "ore")
-  for (p in ptem_pkgs) {
-    skip_if_not_installed(p)
-  }
-  clipr::write_clip("err_fun()")
-  expect_equal(
-    as.character(ptem()),
-    "\"An error message to give ptem\\\\(\\\\) full coverage.\""
-  )
-})
